@@ -1,6 +1,6 @@
 from pulumi import ComponentResource, ResourceOptions, StackReference
 from pulumi_azure_native import storage
-from ..resources import resource_group, storage_account
+from resources import resource_group, storage_account
 import pulumi
 from pulumi import Output
 
